@@ -2,7 +2,7 @@
 # encoding: utf-8
 
 __author__ = "ChenyangGao <https://chenyanggao.github.io>"
-__version__ = (0, 1, 0)
+__version__ = (0, 1, 1)
 __all__ = [
     "create_cookie", "create_morsel", "to_cookie", "to_morsel", 
     "cookie_to_morsel", "morsel_to_cookie", "cookies_to_dict", 
@@ -351,7 +351,11 @@ def cookies_to_dict(
         def predicate(name, _, /) -> bool:
             return contains(name)
     if isinstance(cookies, str):
-        cookie_it = (cookie.split("=", 1) for cookie in CRE_COOKIE_SEP_split(cookies))
+        cookie_it = (
+            ck.split("=", 1) 
+            for cookie in CRE_COOKIE_SEP_split(cookies) 
+            if (ck := cookie.strip())
+        )
         if predicate is not None:
             return {name: val for name, val in cookie_it if predicate(name, val)}
         return dict(cookie_it)
@@ -415,8 +419,9 @@ def cookies_to_str(
         if predicate is None:
             return cookies
         cookie_it: Iterator[tuple[str, Any]] = (
-            tuple(cookie.split("=", 1)) 
-            for cookie in CRE_COOKIE_SEP_split(cookies)
+            tuple(ck.split("=", 1)) 
+            for cookie in CRE_COOKIE_SEP_split(cookies) 
+            if (ck := cookie.strip())
         )
         if predicate is not None:
             cookie_it = ((name, val) for name, val in cookie_it if predicate(name, val))
